@@ -14,7 +14,7 @@ void ga(
   for(k = 0; k < n[0]; k++){
      kdam = dam[k];
      ksire = sire[k];
-     if((kdam != -999) & (ksire != -999)){
+     if((kdam != -999) && (ksire != -999)){
         generation[k] = max(generation[kdam], generation[ksire]) + 1;
      }
      else{
